The scanner API
===============

For most applications, the scanner API is the entry point to Zapf.  It provides
the most high-level access to PILS devices, scanning the :ref:`pils:indexer` for
meta information and devices, and creating :ref:`device <device>` objects.

.. autoclass:: zapf.scan.Scanner
   :members:
